@@ -2218,4 +2218,4 @@ class Builder(Update):
             os.unlink(path.join(builder_path, 'etc/machine-id'))
             return True
         except OSError as e:
-            raise BuilderError(_("failed to find /etc/machine-id"))
+            raise BuilderError(_("Failed to find /etc/machine-id"))
